@@ -9,3 +9,7 @@ colors.split_fg = 15
 colors.info_bg = 'transparent'
 colors.warning_bg = 'transparent'
 colors.error_bg = 'transparent'
+
+colors.file_tree_bg = 'transparent'
+colors.file_tree_selection_fg = {35, 240, 144}
+colors.file_tree_selection_bg = 'transparent'
