@@ -1,6 +1,7 @@
 /// Utilities for configuring and rendering parts of the interface
 use crate::cli::VERSION;
 use crate::editor::{Editor, FileContainer};
+#[cfg(not(target_os = "windows"))]
 use crate::pty::Shell;
 use crate::Feedback;
 use kaolinite::searching::Searcher;
@@ -17,7 +18,11 @@ type LuaRes<T> = RResult<T, LuaError>;
 pub struct Terminal {
     pub mouse_enabled: bool,
     pub scroll_amount: usize,
+    #[cfg(not(target_os = "windows"))]
     pub shell: Shell,
+    #[cfg(target_os = "windows")]
+    #[allow(dead_code)]
+    pub shell: (),
 }
 
 impl Default for Terminal {
@@ -25,7 +30,10 @@ impl Default for Terminal {
         Self {
             mouse_enabled: true,
             scroll_amount: 1,
+            #[cfg(not(target_os = "windows"))]
             shell: Shell::Bash,
+            #[cfg(target_os = "windows")]
+            shell: (),
         }
     }
 }
@@ -42,11 +50,17 @@ impl LuaUserData for Terminal {
             this.scroll_amount = value;
             Ok(())
         });
+        #[cfg(not(target_os = "windows"))]
         fields.add_field_method_get("shell", |_, this| Ok(this.shell));
+        #[cfg(not(target_os = "windows"))]
         fields.add_field_method_set("shell", |_, this, value| {
             this.shell = value;
             Ok(())
         });
+        #[cfg(target_os = "windows")]
+        fields.add_field_method_get("shell", |_, _| Ok("windows not supported"));
+        #[cfg(target_os = "windows")]
+        fields.add_field_method_set("shell", |_, _, _: String| Ok(()));
     }
 }
 
